@@ -1,7 +1,7 @@
 from hugegraph import PyHugeGraph
 
 if __name__ == '__main__':
-    client = PyHugeGraph("xxxx", "8080", user="admin", pwd="admin", graph="hugegraph")
+    client = PyHugeGraph("10.21.3.10", "8080", user="admin", pwd="admin", graph="hugegraph")
 
     """system"""
     res = client.get_graphinfo()
@@ -27,9 +27,3 @@ if __name__ == '__main__':
     # g.removeVertexById("1:vadas")
     print(res)
     g.close()
-
-    """gremlin"""
-    gremlin = client.gremlin()
-    res = gremlin.exec("g.E('S1:josh>2>>L1').outV().inE().outV()")
-    print(res)
-
